@@ -901,7 +901,7 @@ def getCharges(text: str, cnum: str):
 	charges['DescFix'] = charges.index.map(lambda x: len(charges['Description'][x]) - len(charges['Desc2'][x]))
 	charges['DescFix'] = charges.index.map(lambda x: True if charges['Description'][x].strip() == "FELONY PROPERTY" else charges['DescFix'][x])
 	charges['Description'] = charges.index.map(lambda x: re.split(r'.{3}-.{3}-.{3}',charges.Charges[x])[0] if charges.DescFix[x] > 0 else charges['Description'][x])
-	charges['Description'] = charges.index.map(lambda x: re.sub(r'(\d{3}\s[\w\d]{4})','',x) if bool(re.search(r'(\d{3}\s[\w\d]{4})','',x)) else x)
+	charges['Description'] = charges.index.map(lambda x: re.sub(r'(\d{3}\s[\w\d]{4})','',x) if bool(re.search(r'(\d{3}\s[\w\d]{4})',x)) else x)
 	charges.drop(columns=['Desc2','DescFix'],inplace=True)
 
 	###
